@@ -10,6 +10,7 @@ from ._alias_selection import (
 from ._data_format import DatasetDataFormatAccessor
 from ._downscale import DataArrayDownscalingAccessor, DatasetDownscalingAccessor
 from ._metadata import DatasetMetadataAccessor
+from ._setters import DataArraySettersAccessor, DatasetSettersAccessor
 from ._units import DataArrayUnitAccessor, DatasetUnitAccessor
 
 
@@ -20,6 +21,7 @@ class PRIMAP2DatasetAccessor(
     DatasetDataFormatAccessor,
     DatasetDownscalingAccessor,
     DatasetMetadataAccessor,
+    DatasetSettersAccessor,
     DatasetUnitAccessor,
 ):
     """Collection of methods useful for climate policy analysis."""
@@ -30,6 +32,7 @@ class PRIMAP2DataArrayAccessor(
     DataArrayAggregationAccessor,
     DataArrayAliasSelectionAccessor,
     DataArrayDownscalingAccessor,
+    DataArraySettersAccessor,
     DataArrayUnitAccessor,
 ):
     """Collection of methods useful for climate policy analysis."""
