@@ -9,6 +9,8 @@ import xarray as xr
 
 import primap2
 
+from .utils import assert_ds_aligned_equal
+
 
 def test_something_else_entirely(caplog):
     with pytest.raises(ValueError, match=r"ds is not an xr.Dataset"):
@@ -18,20 +20,21 @@ def test_something_else_entirely(caplog):
     assert "object is not an xarray Dataset." in caplog.text
 
 
-def test_valid_ds_pass(minimal_ds, opulent_ds, caplog):
+def test_valid_ds_pass(any_ds, caplog):
     caplog.set_level(logging.INFO)
-    minimal_ds.pr.ensure_valid()
-    opulent_ds.pr.ensure_valid()
+    any_ds.pr.ensure_valid()
     assert not caplog.records
 
 
-def test_io_roundtrip(minimal_ds, opulent_ds, caplog, tmp_path):
+def test_io_roundtrip(any_ds: xr.Dataset, caplog, tmp_path):
+    ds = any_ds
     caplog.set_level(logging.INFO)
-    minimal_ds.pr.to_netcdf(tmp_path / "minimal.nc")
-    opulent_ds.pr.to_netcdf(tmp_path / "opulent.nc")
-    primap2.open_dataset(tmp_path / "minimal.nc").pr.ensure_valid()
-    primap2.open_dataset(tmp_path / "opulent.nc").pr.ensure_valid()
+    ds.pr.to_netcdf(tmp_path / "temp.nc")
+    nds = primap2.open_dataset(tmp_path / "temp.nc")
+    nds.pr.ensure_valid()
     assert not caplog.records
+    xr.testing.assert_identical(ds, nds)
+    assert_ds_aligned_equal(ds, nds)
 
 
 def test_required_dimension_missing(caplog):
@@ -85,7 +88,7 @@ def test_wrong_provenance_value(opulent_ds, caplog):
 
 
 def test_additional_dimension(minimal_ds: xr.Dataset, caplog):
-    ds = minimal_ds.expand_dims({"addl_dim": ["a", "b", "c"]})
+    ds = minimal_ds.expand_dims({"addl_dim": ["a", "b", "c"]})  # type: ignore
     ds.pr.ensure_valid()
     assert "WARNING" in caplog.text
     assert (
@@ -105,22 +108,6 @@ def test_wrong_dimension_key(minimal_ds, caplog):
     assert "'asdf' not in the format 'dim (category_set)'." in caplog.text
 
 
-def test_not_one_source(minimal_ds: xr.Dataset, caplog):
-    ds = minimal_ds.loc[{"source": "RAND2020"}]
-    ds["source"] = []
-    with pytest.raises(ValueError, match=r"Exactly one source required"):
-        ds.pr.ensure_valid()
-    assert "ERROR" in caplog.text
-    assert "Exactly one source required per data set." in caplog.text
-
-    caplog.clear()
-    ds["source"] = ["a", "b"]
-    with pytest.raises(ValueError, match=r"Exactly one source required"):
-        ds.pr.ensure_valid()
-    assert "ERROR" in caplog.text
-    assert "Exactly one source required per data set." in caplog.text
-
-
 def test_missing_sec_cat(minimal_ds, caplog):
     minimal_ds.attrs["sec_cats"] = ["missing"]
     with pytest.raises(ValueError, match="Secondary category 'missing' not in dims"):
